;; -*- no-byte-compile: t; lexical-binding: nil -*-
(define-package "verb" "20251019.1842"
  "Organize and send HTTP requests."
  '((emacs "26.3"))
  :url "https://github.com/federicotdn/verb"
  :commit "5f5381333ee5d8ff3df7d1d01b9becc377bb1415"
  :revdesc "5f5381333ee5"
  :keywords '("tools")
  :authors '(("Federico Tedin" . "federicotedin@gmail.com"))
  :maintainers '(("Federico Tedin" . "federicotedin@gmail.com")))
